# coding: utf-8

# flake8: noqa

"""
    MeMaS CP APIs

    This is the Control Plane APIs for MeMaS (Memory Management Service).  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: max.yu@memas.ai
    Generated by: https://openapi-generator.tech
"""

__version__ = "1.0.0"

# import ApiClient
from memas_sdk.api_client import ApiClient

# import Configuration
from memas_sdk.configuration import Configuration

# import exceptions
from memas_sdk.exceptions import OpenApiException
from memas_sdk.exceptions import ApiAttributeError
from memas_sdk.exceptions import ApiTypeError
from memas_sdk.exceptions import ApiValueError
from memas_sdk.exceptions import ApiKeyError
from memas_sdk.exceptions import ApiException



import typing_extensions

from memas_sdk.paths import PathValues
from memas_sdk.apis.paths.cp_create_user import CpCreateUser
from memas_sdk.apis.paths.cp_create_corpus import CpCreateCorpus

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.CP_CREATE_USER: CpCreateUser,
        PathValues.CP_CREATE_CORPUS: CpCreateCorpus,
    }
)

path_to_api = PathToApi(
    {
        PathValues.CP_CREATE_USER: CpCreateUser,
        PathValues.CP_CREATE_CORPUS: CpCreateCorpus,
    }
)



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from memas_sdk.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    CP_CREATE_USER = "/cp/create_user"
    CP_CREATE_CORPUS = "/cp/create_corpus"



import typing_extensions

from memas_sdk.apis.tags import TagValues
from memas_sdk.apis.tags.cp_api import CpApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.CP: CpApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.CP: CpApi,
    }
)



# coding: utf-8

"""
    MeMaS CP APIs

    This is the Control Plane APIs for MeMaS (Memory Management Service).  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: max.yu@memas.ai
    Generated by: https://openapi-generator.tech
"""

import unittest

import memas_sdk
from memas_sdk.model.corpus_pathname import CorpusPathname
from memas_sdk import configuration


class TestCorpusPathname(unittest.TestCase):
    """CorpusPathname unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MeMaS CP APIs

    This is the Control Plane APIs for MeMaS (Memory Management Service).  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: max.yu@memas.ai
    Generated by: https://openapi-generator.tech
"""

from memas_sdk.paths.cp_create_corpus.post import CreateCorpus
from memas_sdk.paths.cp_create_user.post import CreateUser


class CpApi(
    CreateCorpus,
    CreateUser,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    MeMaS CP APIs

    This is the Control Plane APIs for MeMaS (Memory Management Service).  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: max.yu@memas.ai
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from memas_sdk import schemas  # noqa: F401
CorpusPathname = schemas.StrSchema



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from memas_sdk.paths.cp_create_user import Api

from memas_sdk.paths import PathValues

path = PathValues.CP_CREATE_USER


# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from memas_sdk.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    CP = "cp"



# coding: utf-8

"""
    MeMaS CP APIs

    This is the Control Plane APIs for MeMaS (Memory Management Service).  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: max.yu@memas.ai
    Generated by: https://openapi-generator.tech
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "memas-sdk"
VERSION = "0.1.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi >= 14.5.14",
    "frozendict ~= 2.3.4",
    "python-dateutil ~= 2.7.0",
    "setuptools >= 21.0.0",
    "typing_extensions ~= 4.3.0",
    "urllib3 ~= 1.26.7",
]

setup(
    name=NAME,
    version=VERSION,
    description="MeMaS CP APIs",
    author="OpenAPI Generator community",
    author_email="max.yu@memas.ai",
    url="https://github.com/memas-ai/MeMaS-python-sdk",
    keywords=["OpenAPI", "OpenAPI-Generator", "MeMaS CP APIs"],
    python_requires=">=3.7",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache 2.0",
    long_description="""\
    This is the Control Plane client for MeMaS (Memory Management Service). See https://github.com/memas-ai/MeMaS for more details.  # noqa: E501
    """
)
